;;; color-mate-util.el -- Color-Mate utility routines.  -*-emacs-lisp-*-

;; Copyright (C) HIROSHI Yokota

;; Author: Hiroshi Yokota <y5t0964@students.chiba-u.ac.jp>
;; Maintainer: Hiroshi Yokota <y5t0964@students.chiba-u.ac.jp>
;; Version: 9.0
;; Keywords: color-mate
;; Content-Type: text/plain; charset=x-euc-jp

;; $Id: color-mate-util.el,v 9.1 1998/02/17 20:25:43 elca Exp $

(defun color-mate:emacs-version ()
  "return emacs major version"
  (progn
   (string-to-int emacs-version)))

(defun color-mate:is-xemacs ()
  "return t if you using XEmacs."
  (progn
    (string-match "XEmacs" emacs-version)))

(defun color-mate:get-alist-value (key alist)
  "get value from alist"
  (progn
    (cdr (assoc key alist))
    ))

;; xemacs $BMQ$N(B emacs $B8_494X?t!#(B
(if (color-mate:is-xemacs)
    (defun set-cursor-color (color)
      "set cursor color from color-mate."
      (set-face-background 'text-cursor color))
)

;; emacs/xemacs $B$N:9$r5[<}$9$k4X?t(B
(defun color-mate:face-background (emacs-face xemacs-face)
  (progn
    (if (color-mate:is-xemacs)
	(custom-face-background xemacs-face)
      (face-background emacs-face))))
(defun color-mate:face-foreground (emacs-face xemacs-face)
  (progn
    (if (color-mate:is-xemacs)
	(custom-face-foreground xemacs-face)
      (face-foreground emacs-face))))
(defun color-mate:frame-param-or-face-background (emacs-param xemacs-face)
  (progn
    (if (color-mate:is-xemacs)
	(custom-face-background xemacs-face)
      (cdr (assoc emacs-param
		  (frame-parameters (selected-frame)))))))
(defun color-mate:frame-param-or-face-foreground (emacs-param xemacs-face)
  (progn
    (if (color-mate:is-xemacs)
	(custom-face-foreground xemacs-face)
      (cdr (assoc emacs-param
		  (frame-parameters (selected-frame)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; $BFbIt$G;HMQ$9$k4X?t(B
(defvar color-mate:*tmp* nil "temporary valuable")
(defvar color-mate:*tmp-alist* '() "temporary valuable")
(defun color-mate:_set-alist-if-string (alist ball-val alist-val)
  "This is Color-Mate's internal function. Don't use it."
  (if (stringp
       (setq color-mate:*tmp* (color-mate:get-alist-value ball-val alist)))
      (setq color-mate:*tmp-alist*
	    (cons (cons alist-val color-mate:*tmp*) color-mate:*tmp-alist*))))

(defun color-mate:_set-alist-if-integer (alist ball-val alist-val)
  "This is Color-Mate's internal function. Don't use it."
  (if (integerp
       (setq color-mate:*tmp* (color-mate:get-alist-value ball-val alist)))
      (setq color-mate:*tmp-alist*
	    (cons (cons alist-val color-mate:*tmp*) color-mate:*tmp-alist*))))

(defun color-mate:_set-face-if-string (alist bg fg face)
  "This is Color-Mate's internal function. Don't use it."
  (progn
    (if (stringp
	 (setq color-mate:*tmp* (color-mate:get-alist-value bg alist)))
	(set-face-background face color-mate:*tmp*))
    (if (stringp
	 (setq color-mate:*tmp* (color-mate:get-alist-value fg alist)))
	(set-face-foreground face color-mate:*tmp*))))

(provide 'color-mate-util)

;;; color-mate-util.el ends here.
