;;; color-mate.el -- Coloring mule/emacs to more easier and more fun.

;; Copyright (C) HIROSHI Yokota

;; Author: Hiroshi Yokota <y5t0964@students.chiba-u.ac.jp>
;; Maintainer: Hiroshi Yokota <y5t0964@students.chiba-u.ac.jp>
;; Version: 9.0
;; Keywords: color hilit19 font-lock color-mate
;; Content-Type: text/plain; charset=x-euc-jp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Color-Mate  Ver.9.0
;;         by  ͵ (y5t0964@students.chiba-u.ac.jp)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Coloring mule/emacs to more easier and more fun.
;;   mule / emacs ǡѤƸ䤹̤ˤޤ
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Commentary:
;; (1) Add file "color-mate.Xdefaults.add"'s contents to your ~/.Xdefaults.
;; (2) Make color-mate-rgb.el. This file make from rgb.txt and rgb2el.pl
;;     (Perl script).
;; (3) Write these lines to your ~/.emacs
;;        (if (and (>= (string-to-int emacs-version) 19)
;;	           window-system )
;;            (progn
;;               (require 'color-mate)
;;               (color-mate)
;;               ))
;;     or Add "color-mate.emacs.add"'s contents to your ~/.emacs.
;;
;;  If you want to more, see color-mate-face.el.
;;
;;
;; <feature tree>
;; Color-Mate
;;   |
;;   +- color-mate.el
;;   |    +- color-mate-rgb.el
;;   |    +- color-mate-e19.el
;;   |    +- color-mate-xemacs.el
;;   |    +- color-mate-util.el
;;   |
;;   +- color-mate-face.el
;;   |    +- <hilit19.el>
;;   |    +- <font-lock.el>
;;   |    +- <paren.el>
;;   |    +- <canna.el>
;;   |    +- <can-n-egg.el>
;;   |
;;   +- kanakan-cursor/skk-cursor.el
;;   |    +- color-mate-util.el
;;   +- kanakan-cursor/skk-cursor2.el
;;   +- kanakan-cursor/egg-cursor.el
;;   |    +- color-mate-util.el
;;   |    +- <egg.el>
;;   +- kanakan-cursor/canna-cursor.el
;;   |    +- color-mate-util.el
;;   |    +- <canna.el>
;;   +- kanakan-cursor/sj3-cursor.el
;;   |    +- color-mate-util.el
;;   |    +- <egg.el>
;;   +- kanakan-cursor/leim-cursor.el

;$Id: color-mate.el,v 9.1 1998/02/17 20:31:13 elca Exp $

;; -*-mode: emacs-lisp-*-

;;; Code:

;;
;; Color-Mate.el
;;

;----------------;
; Сɽ
;----------------;
(defconst color-mate:version-string "Color-Mate Ver.9.0 based on mule 2.3(emacs 19.34.2) / emacs 19.34.1, 20.2.1 / xemacs 20.2 : color-mate.el 1998/Feb/18")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                       СɽѴؿ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun color-mate:version ()
  "Show Color-Mate version."
  (interactive)
  (message (concat (substring color-mate:version-string 0 72) " ...")) )

;----------------------------------------------------------------------;
;                         Color-Mate ѿ
;----------------------------------------------------------------------;
(defvar color-mate:color-ball '() "Color-Mate definition file name")
(defvar color-mate:color-ball-file "SunnyDay"
  "Color-Mate definition file name")
(defvar color-mate:color-history nil
  "Color-Mate color history buffer")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                        ؿ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; ؿΡmule/emacs ˿ɤ롣
;
(defun color-mate ()
  "Coloring mule/emacs."
  (interactive)
  (if window-system
      (progn
	(message "Loading Color-Mate coloring system...")

	(load color-mate:color-ball-file) ; եɤ߹

	(color-mate:set-default-frame)

	(message "Loading Color-Mate coloring system...done"))
    (progn
      (error "color-mate.el requires window system. stop."))
    )
  )


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;               ե졼δͤ롣
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun color-mate:set-default-frame ()
  "Set default settings to coloring."
  (progn
    (if (color-mate:is-xemacs)
	;; XEmacs λ
	(progn
	  (require 'color-mate-xemacs)
	  (color-mate:xemacs-set-default-frame color-mate:color-ball))
      ;; Emacs/Mule λ
      (progn
	(require 'color-mate-e19)
	(color-mate:e19-set-default-frame color-mate:color-ball)))
    ))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                 ߤΥե졼οѹ롣
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun color-mate:set-current-frame (alist)
  "Coloring current frame."
  (progn
    (if (color-mate:is-xemacs)
	;; XEmacs λ
	(progn
	  (require 'color-mate-xemacs)
	  (color-mate:xemacs-set-current-frame alist))
      ;; Emacs/Mule λ
      (progn
	(require 'color-mate-e19)
	(color-mate:e19-set-current-frame alist)))
    ))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                  󥿥饯ƥѴؿ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 󥿥饯ƥˤäͤƤ줾ѿ
;  color-mate-set-current-frame ؿˤäƸߤΥե졼ο
; ѹ롣
;
(defun color-mate:set-color ( modeline-bg modeline-fg
			      region-bg   region-fg
			      frame-bg    frame-fg
			      cursor
			      mouse )
  "Change current frame color interactively.
Just press return key to use old value."
  
  ; ͤ롣ͤǥեͤȤɽ롣
  ; TAB, SPACE ˤ˥塼 M-n, M-p ˤλȤǽ
  (interactive
   (progn
     (require 'color-mate-rgb)      ; rgb ơ֥θƤӽФ
     
     (mapcar '(lambda (x)
		(completing-read x color-mate:rgb-table nil nil nil
				 'color-mate:color-history))
	     
	     (list
	      (format "Modeline background color (default %s): "
		      (color-mate:face-background 'modeline 'modeline))
	      (format "Modeline foreground color (default %s): "
		      (color-mate:face-foreground 'modeline 'modeline))
	      (format "Region background color (default %s): "
		      (color-mate:face-background 'region 'zmacs-region))
	      (format "Region foreground color (default %s): "
		      (color-mate:face-foreground 'region 'zmacs-region))
	      (format "Frame background color (default %s): "
		      (color-mate:frame-param-or-face-background
		       'background-color 'default))
	      (format "Frame foreground color (default %s): "
		      (color-mate:frame-param-or-face-foreground
		       'foreground-color 'default))
	      (format "Cursor color (default %s): "
		      (color-mate:frame-param-or-face-background
		       'cursor-color 'text-cursor))
	      (format "Mouse cursor name (default %s): "
		      (color-mate:frame-param-or-face-foreground
		       'mouse-color 'pointer))
	    ))))
  (progn
    (setq color-mate:*tmp-alist* '())

    ;; ͤꤵƤФͤ򡢤ƤʤͤѤ
    (if (not (equal modeline-bg ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'modeline-background-color modeline-bg)
	       color-mate:*tmp-alist*)))
    (if (not (equal modeline-fg ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'modeline-foreground-color modeline-fg)
	       color-mate:*tmp-alist*)))
    
    (if (not (equal region-bg ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'region-background-color region-bg)
		   color-mate:*tmp-alist*)))
    (if (not (equal region-fg ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'region-foreground-color region-fg)
	       color-mate:*tmp-alist*)))

    (if (not (equal frame-bg ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'frame-background-color frame-bg)
	       color-mate:*tmp-alist*)))
    (if (not (equal frame-fg ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'frame-foreground-color frame-fg)
	       color-mate:*tmp-alist*)))

    (if (not (equal cursor ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'cursor-color cursor)
	       color-mate:*tmp-alist*)))
    (if (not (equal mouse ""))
	(setq color-mate:*tmp-alist*
	      (cons
	       (cons 'mouse-color mouse)
	       color-mate:*tmp-alist*)))
	
    ;; 忧
    (color-mate:set-current-frame color-mate:*tmp-alist*)
    ))


(require 'color-mate-util)

(provide 'color-mate) ; feature ȤϿ

;;; color-mate.el ends here
